@@ -26,43 +26,45 @@
 #include <string.h>
 #endif
 
+#include <glib.h>
+#include <gio/gio.h>
 #include <glib-object.h>
 
-#include <dbus/dbus-glib.h>
-
 #include "xfconf.h"
 #include "common/xfconf-marshal.h"
 #include "xfconf-private.h"
 #include "common/xfconf-alias.h"
 
 static guint xfconf_refcnt = 0;
-static DBusGConnection *dbus_conn = NULL;
-static DBusGProxy *dbus_proxy = NULL;
+
+static GDBusConnection *gdbus = NULL;
+static GDBusProxy *gproxy = NULL;
 static GHashTable *named_structs = NULL;
 
 
 /* private api */
 
-DBusGConnection *
-_xfconf_get_dbus_g_connection(void)
+GDBusConnection *
+_xfconf_get_gdbus_connection(void)
 {
     if(!xfconf_refcnt) {
         g_critical("xfconf_init() must be called before attempting to use libxfconf!");
         return NULL;
     }
 
-    return dbus_conn;
+    return gdbus;
 }
 
-DBusGProxy *
-_xfconf_get_dbus_g_proxy(void)
+
+GDBusProxy *
+_xfconf_get_gdbus_proxy(void)
 {
     if(!xfconf_refcnt) {
         g_critical("xfconf_init() must be called before attempting to use libxfconf!");
         return NULL;
     }
 
-    return dbus_proxy;
+    return gproxy;
 }
 
 XfconfNamedStruct *
@@ -78,35 +80,6 @@ _xfconf_named_struct_free(XfconfNamedStruct *ns)
     g_slice_free(XfconfNamedStruct, ns);
 }
 
-
-
-static void
-xfconf_static_dbus_init(void)
-{
-    static gboolean static_dbus_inited = FALSE;
-
-    if(!static_dbus_inited) {
-        dbus_g_error_domain_register(XFCONF_ERROR, "org.xfce.Xfconf.Error",
-                                     XFCONF_TYPE_ERROR);
-
-        dbus_g_object_register_marshaller(_xfconf_marshal_VOID__STRING_STRING_BOXED,
-                                          G_TYPE_NONE,
-                                          G_TYPE_STRING,
-                                          G_TYPE_STRING,
-                                          G_TYPE_VALUE,
-                                          G_TYPE_INVALID);
-        dbus_g_object_register_marshaller(_xfconf_marshal_VOID__STRING_STRING,
-                                          G_TYPE_NONE,
-                                          G_TYPE_STRING,
-                                          G_TYPE_STRING,
-                                          G_TYPE_INVALID);
-
-        static_dbus_inited = TRUE;
-    }
-}
-
-
-
 /* public api */
 
 /**
@@ -131,23 +104,19 @@ xfconf_init(GError **error)
     g_type_init();
 #endif
 
-    xfconf_static_dbus_init();
+    gdbus = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, error);
 
-    dbus_conn = dbus_g_bus_get(DBUS_BUS_SESSION, error);
-    if(!dbus_conn)
+    if (!gdbus)
         return FALSE;
 
-    dbus_proxy = dbus_g_proxy_new_for_name(dbus_conn,
-                                           "org.xfce.Xfconf",
-                                           "/org/xfce/Xfconf",
-                                           "org.xfce.Xfconf");
-
-    dbus_g_proxy_add_signal(dbus_proxy, "PropertyChanged",
-                            G_TYPE_STRING, G_TYPE_STRING, G_TYPE_VALUE,
-                            G_TYPE_INVALID);
-    dbus_g_proxy_add_signal(dbus_proxy, "PropertyRemoved",
-                            G_TYPE_STRING, G_TYPE_STRING,
-                            G_TYPE_INVALID);
+    gproxy = g_dbus_proxy_new_sync(gdbus,
+                                   G_DBUS_PROXY_FLAGS_NONE,
+                                   NULL,
+                                   "org.xfce.Xfconf",
+                                   "/org/xfce/Xfconf",
+                                   "org.xfce.Xfconf",
+                                   NULL,
+                                   NULL);
 
     ++xfconf_refcnt;
     return TRUE;
@@ -180,12 +149,6 @@ xfconf_shutdown(void)
         named_structs = NULL;
     }
 
-    g_object_unref(G_OBJECT(dbus_proxy));
-    dbus_proxy = NULL;
-
-    dbus_g_connection_unref(dbus_conn);
-    dbus_conn = NULL;
-
     --xfconf_refcnt;
 }
 
